pub enum CrashIntrospectRequest {
FindDriverCrash {
process_koid: u64,
thread_koid: u64,
responder: CrashIntrospectFindDriverCrashResponder,
},
}Expand description
When a thread from a component using the driver runner crashes, the thread koid along with other information is stored. This protocol can be used to retrieve that stored information.
Variants
FindDriverCrash
Given a process and thread koid, returns the information that was stored when the driver host observed a crash from that thread.
The information for a crash is deleted when it is accessed.
If there is no information available on the given thread koid,
zx::Status::NOT_FOUND is returned.
Implementations
Sourceimpl CrashIntrospectRequest
impl CrashIntrospectRequest
pub fn into_find_driver_crash( self, ) -> Option<(u64, u64, CrashIntrospectFindDriverCrashResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL